@@ -57,13 +57,13 @@ FiltersView::FiltersView(QWidget * parent) : QWidget(parent), ui(new Ui::Filters
   ui->treeView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
   ui->treeView->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
-  connect(delegate, SIGNAL(commitData(QWidget *)), this, SLOT(onRenameFaveFinished(QWidget *)));
-  connect(ui->treeView, SIGNAL(returnKeyPressed()), this, SLOT(onReturnKeyPressedInFiltersTree()));
-  connect(ui->treeView, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
-  connect(&_model, SIGNAL(itemChanged(QStandardItem *)), this, SLOT(onItemChanged(QStandardItem *)));
+  connect(delegate, &FilterTreeItemDelegate::commitData, this, &FiltersView::onRenameFaveFinished);
+  connect(ui->treeView, &TreeView::returnKeyPressed, this, &FiltersView::onReturnKeyPressedInFiltersTree);
+  connect(ui->treeView, &TreeView::clicked, this, &FiltersView::onItemClicked);
+  connect(&_model, &QStandardItemModel::itemChanged, this, &FiltersView::onItemChanged);
 
   ui->treeView->setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(ui->treeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onCustomContextMenu(QPoint)));
+  connect(ui->treeView, &TreeView::customContextMenuRequested, this, &FiltersView::onCustomContextMenu);
   _faveContextMenu = nullptr;
   _filterContextMenu = nullptr;
   ui->treeView->installEventFilter(this);
@@ -167,6 +167,7 @@ void FiltersView::selectFave(const QString & hash)
     if (fave) {
       ui->treeView->setCurrentIndex(fave->index());
       ui->treeView->scrollTo(fave->index(), QAbstractItemView::PositionAtCenter);
+      updateIndexBeforeClick();
     }
   }
 }
@@ -180,6 +181,7 @@ void FiltersView::selectActualFilter(const QString & hash, const QList<QString>
       if (filter && (filter->hash() == hash)) {
         ui->treeView->setCurrentIndex(filter->index());
         ui->treeView->scrollTo(filter->index(), QAbstractItemView::PositionAtCenter);
+        updateIndexBeforeClick();
         return;
       }
     }
@@ -397,7 +399,11 @@ void FiltersView::editSelectedFaveName()
 
 void FiltersView::expandAll()
 {
+  auto index = ui->treeView->currentIndex();
   ui->treeView->expandAll();
+  if (index.isValid()) {
+    ui->treeView->scrollTo(index, QAbstractItemView::PositionAtCenter);
+  }
 }
 
 void FiltersView::collapseAll()
@@ -467,12 +473,15 @@ void FiltersView::onReturnKeyPressedInFiltersTree()
 
 void FiltersView::onItemClicked(QModelIndex index)
 {
-  FilterTreeItem * item = filterTreeItemFromIndex(index);
-  if (item) {
-    emit filterSelected(item->hash());
-  } else {
-    emit filterSelected(QString());
+  if (index != _indexBeforeClick) {
+    FilterTreeItem * item = filterTreeItemFromIndex(index);
+    if (item) {
+      emit filterSelected(item->hash());
+    } else {
+      emit filterSelected(QString());
+    }
   }
+  updateIndexBeforeClick();
 }
 
 void FiltersView::onItemChanged(QStandardItem * item)
@@ -668,15 +677,15 @@ QMenu * FiltersView::itemContextMenu(MenuType type, FilterTreeItem * item)
   switch (type) {
   case MenuType::Fave:
     action = menu->addAction(tr("Rename Fave"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRenameFave()));
+    connect(action, &QAction::triggered, this, &FiltersView::onContextMenuRenameFave);
     action = menu->addAction(tr("Remove Fave"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRemoveFave()));
+    connect(action, &QAction::triggered, this, &FiltersView::onContextMenuRemoveFave);
     action = menu->addAction(tr("Clone Fave"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
+    connect(action, &QAction::triggered, this, &FiltersView::onContextMenuAddFave);
     break;
   case MenuType::Filter:
     action = menu->addAction(tr("Add Fave"));
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
+    connect(action, &QAction::triggered, this, &FiltersView::onContextMenuAddFave);
     break;
   }
   TagColorSet tags = item->tags();
@@ -730,6 +739,11 @@ void FiltersView::toggleItemTag(FilterTreeItem * item, TagColor color)
   }
 }
 
+void FiltersView::updateIndexBeforeClick()
+{
+  _indexBeforeClick = ui->treeView->currentIndex();
+}
+
 FilterTreeItem * FiltersView::findFave(const QString & hash)
 {
   const int count = _faveFolder ? _faveFolder->rowCount() : 0;
