@@ -64,9 +64,6 @@
 #include "Utils.h"
 #include "Widgets/VisibleTagSelector.h"
 #include "ui_mainwindow.h"
-#ifndef gmic_core
-#include "CImg.h"
-#endif
 #include "gmic.h"
 
 namespace
@@ -816,6 +813,7 @@ void MainWindow::onFullImageProcessingError(const QString & message)
 
 void MainWindow::onInputModeChanged(InputMode mode)
 {
+  PersistentMemory::clear();
   ui->previewWidget->setFullImageSize(LayersExtentProxy::getExtent(mode));
   ui->previewWidget->sendUpdateRequest();
 }
