@@ -41,9 +41,9 @@ namespace Ui
 class MainWindow;
 }
 
-namespace cimg_library
+namespace gmic_library
 {
-template <typename T> struct CImgList;
+template <typename T> struct gmic_list;
 }
 
 namespace GmicQt
