@@ -105,7 +105,7 @@ const QString & pluginFullName()
   if (result.isEmpty()) {
     result = QString("G'MIC-Qt %1- %2 %3 bits - %4" BETA_SUFFIX)
                  .arg(GmicQtHost::ApplicationName.isEmpty() ? QString() : QString("for %1 ").arg(GmicQtHost::ApplicationName))
-                 .arg(cimg_library::cimg::stros())
+                 .arg(gmic_library::cimg::stros())
                  .arg(sizeof(void *) == 8 ? 64 : 32)
                  .arg(gmicVersionString());
   }
